import { Command, CommandContribution, CommandRegistry, MessageService } from '@theia/core';
import { ApplicationShell, OpenerService, QuickInputService } from '@theia/core/lib/browser';
import { ContextKeyService } from '@theia/core/lib/browser/context-key-service';
import { ApplicationShellMouseTracker } from '@theia/core/lib/browser/shell/application-shell-mouse-tracker';
import { CommandService } from '@theia/core/lib/common/command';
import { EditorManager } from '@theia/editor/lib/browser';
import { WorkspaceService } from '@theia/workspace/lib/browser/workspace-service';
import { DiffService } from '@theia/workspace/lib/browser/diff-service';
import { URI } from '@theia/core/shared/vscode-uri';
import { PluginServer } from '@theia/plugin-ext/lib/common/plugin-protocol';
import { TerminalFrontendContribution } from '@theia/terminal/lib/browser/terminal-frontend-contribution';
import { QuickOpenWorkspace } from '@theia/workspace/lib/browser/quick-open-workspace';
import { TerminalService } from '@theia/terminal/lib/browser/base/terminal-service';
import { FileService } from '@theia/filesystem/lib/browser/file-service';
import { CallHierarchyServiceProvider, CallHierarchyService } from '@theia/callhierarchy/lib/browser';
import { TypeHierarchyServiceProvider, TypeHierarchyService } from '@theia/typehierarchy/lib/browser';
import { MonacoTextModelService } from '@theia/monaco/lib/browser/monaco-text-model-service';
import { WindowService } from '@theia/core/lib/browser/window/window-service';
import { CodeEditorWidgetUtil } from '@theia/plugin-ext/lib/main/browser/menus/vscode-theia-menu-mappings';
export declare namespace VscodeCommands {
    const OPEN: Command;
    const OPEN_WITH: Command;
    const OPEN_FOLDER: Command;
    const DIFF: Command;
    const INSTALL_FROM_VSIX: Command;
}
export interface UsbDeviceData {
    readonly deviceClass: number;
    readonly deviceProtocol: number;
    readonly deviceSubclass: number;
    readonly deviceVersionMajor: number;
    readonly deviceVersionMinor: number;
    readonly deviceVersionSubminor: number;
    readonly manufacturerName?: string;
    readonly productId: number;
    readonly productName?: string;
    readonly serialNumber?: string;
    readonly usbVersionMajor: number;
    readonly usbVersionMinor: number;
    readonly usbVersionSubminor: number;
    readonly vendorId: number;
}
export interface SerialPortData {
    readonly usbVendorId?: number | undefined;
    readonly usbProductId?: number | undefined;
}
export interface HidDeviceData {
    readonly opened: boolean;
    readonly vendorId: number;
    readonly productId: number;
    readonly productName: string;
    readonly collections: [];
}
export declare class PluginVscodeCommandsContribution implements CommandContribution {
    protected readonly commandService: CommandService;
    protected readonly contextKeyService: ContextKeyService;
    protected readonly editorManager: EditorManager;
    protected readonly shell: ApplicationShell;
    protected readonly diffService: DiffService;
    protected readonly openerService: OpenerService;
    protected readonly mouseTracker: ApplicationShellMouseTracker;
    protected readonly quickInput: QuickInputService;
    protected readonly workspaceService: WorkspaceService;
    protected readonly terminalContribution: TerminalFrontendContribution;
    protected readonly quickOpenWorkspace: QuickOpenWorkspace;
    protected readonly terminalService: TerminalService;
    protected readonly codeEditorWidgetUtil: CodeEditorWidgetUtil;
    protected readonly pluginServer: PluginServer;
    protected readonly fileService: FileService;
    protected readonly callHierarchyProvider: CallHierarchyServiceProvider;
    protected readonly typeHierarchyProvider: TypeHierarchyServiceProvider;
    protected readonly textModelService: MonacoTextModelService;
    protected readonly windowService: WindowService;
    protected readonly messageService: MessageService;
    private openWith;
    registerCommands(commands: CommandRegistry): void;
    private resolveLanguageId;
    protected getCallHierarchyServiceForUri(resource: URI): Promise<CallHierarchyService | undefined>;
    protected getTypeHierarchyServiceForUri(resource: URI): Promise<TypeHierarchyService | undefined>;
}
//# sourceMappingURL=plugin-vscode-commands-contribution.d.ts.map